@@ -98,11 +98,16 @@ predict.bgvar <- function(object, ..., n.ahead=1, constr=NULL, constr_sd=NULL, q
   
   pred_store <- array(NA,dim=c(thindraws,bigK,n.ahead))
   # start loop here
-  if(verbose) cat("Start computing predictions...\n")
+  if(verbose){
+    if(flag_cond)
+      cat("Start computing conditional predictions...\n")
+    else
+      cat("Start computing predictions...\n")
+  }
   for(irep in 1:thindraws){
     #Step I: Construct a global VC matrix Omega_t
-    Ginv    <- Ginv_large[irep,,]
-    Sig_t   <- Ginv%*%(S_large[irep,,])%*%t(Ginv)
+    Ginv    <- Ginv_large[,,irep]
+    Sig_t   <- Ginv%*%(S_large[,,irep])%*%t(Ginv)
     Sig_t   <- as.matrix(Sig_t)
     zt      <- Xn[bigT,]
     z1      <- zt
@@ -111,22 +116,29 @@ predict.bgvar <- function(object, ..., n.ahead=1, constr=NULL, constr_sd=NULL, q
     y2      <- NULL
     
     #gets companion form
-    aux   <- .get_companion(A_large[irep,,],varndxv)
+    aux   <- .get_companion(A_large[,,irep],varndxv)
     Mm    <- aux$MM
     Jm    <- aux$Jm
     Jsigt <- Jm%*%Sig_t%*%t(Jm)
     # this is the forecast loop
+    stop <- FALSE
     for(ih in 1:n.ahead){
       z1      <- Mm%*%z1
       Sigma00 <- Mm%*%Sigma00%*%t(Mm) + Jsigt
       chol_varyt <- try(t(chol(Sigma00[1:bigK,1:bigK])),silent=TRUE)
-      if(is(chol_varyt,"try-error")){
-        yf <- mvrnorm(1,mu=z1[1:bigK],Sigma00[1:bigK,1:bigK])
-      }else{
+      if(is(chol_varyt,"matrix")){
         yf <- z1[1:bigK]+chol_varyt%*%rnorm(bigK,0,1)
       }
+      if(is(chol_varyt,"try-error")){
+        yf <- try(mvrnorm(1,mu=z1[1:bigK],Sigma00[1:bigK,1:bigK]),silent=TRUE)
+      }
+      if(is(yf,"try-error")){
+        stop = TRUE
+        break # break inner loop
+      }
       y2 <- cbind(y2,yf)
     }
+    if(stop){next} # continue outer loop
     pred_store[irep,,] <- y2
   }
   #----------do conditional forecasting -------------------------------------------#
@@ -134,13 +146,14 @@ predict.bgvar <- function(object, ..., n.ahead=1, constr=NULL, constr_sd=NULL, q
     cond_store <- array(NA, c(thindraws, bigK, n.ahead))
     dimnames(cond_store)[[2]] <- varNames
     
-    if(verbose) cat("Start computing conditional predictions...\n")
     if(verbose) pb <- txtProgressBar(min = 0, max = thindraws, style = 3)
     for(irep in 1:thindraws){
       pred    <- pred_store[irep,,]
-      Sigma_u <- Ginv_large[irep,,]%*%S_large[irep,,]%*%t(Ginv_large[irep,,])
-      irf     <- .impulsdtrf(B=adrop(F_large[irep,,,,drop=FALSE],drop=1),
-                             smat=t(chol(Sigma_u)),nstep=n.ahead)
+      Sigma_u <- Ginv_large[,,irep]%*%S_large[,,irep]%*%t(Ginv_large[,,irep])
+      chol_varyt <- try(t(chol(Sigma_u)), silent=TRUE)
+      if(is(chol_varyt,"try-error")) {next}
+      irf     <- .impulsdtrf(B=adrop(F_large[,,,irep,drop=FALSE],drop=4),
+                             smat=chol_varyt,nstep=n.ahead)
       
       temp <- as.vector(constr) + rnorm(bigK*n.ahead,0,as.vector(constr_sd))
       constr_use <- matrix(temp,n.ahead,bigK)
@@ -194,8 +207,8 @@ predict.bgvar <- function(object, ..., n.ahead=1, constr=NULL, constr_sd=NULL, q
   yfull <- object$args$yfull
   if(hold.out>0){
     lps.stats <- array(0,dim=c(bigK,2,hold.out), dimnames=list(colnames(xglobal),c("mean","sd"),seq(1,hold.out)))
-    lps.stats[,"mean",] <- apply(pred_store[,,1:hold.out],c(2:3),mean)
-    lps.stats[,"sd",]   <- apply(pred_store[,,1:hold.out],c(2:3),sd)
+    lps.stats[,"mean",] <- apply(pred_store[,,1:hold.out],c(2:3),mean,na.rm=TRUE)
+    lps.stats[,"sd",]   <- apply(pred_store[,,1:hold.out],c(2:3),sd,na.rm=TRUE)
     hold.out.sample<-yfull[(nrow(yfull)+1-hold.out):nrow(yfull),,drop=FALSE]
   }else{
     lps.stats<-NULL
@@ -264,7 +277,7 @@ lps.bgvar.pred <- function(object, ...){
   h        <- nrow(hold.out)
   K        <- ncol(hold.out)
   if(is.null(hold.out)){
-    stop("Please submit a forecast object that includes a hold out sample for evaluation (set h>0 when estimating the model with bgvar)!")
+    stop("Please submit a forecast object that includes a hold out sample for evaluation (set hold.out>0 when estimating the model with bgvar)!")
   }
   lps.stats  <- object$lps.stats
   lps.scores <- matrix(NA,h,K)
@@ -304,7 +317,7 @@ rmse.bgvar.pred <- function(object, ...){
   h        <- nrow(hold.out)
   K        <- ncol(hold.out)
   if(is.null(hold.out)){
-    stop("Please submit a forecast object that includes a hold out sample for evaluation (set h>0 in fcast)!")
+    stop("Please submit a forecast object that includes a hold out sample for evaluation (set hold.out>0 in fcast)!")
   }
   lps.stats   <- object$lps.stats
   rmse.scores <- matrix(NA,h,K)
